const quizData = [
  { question: "Are you more outgoing or reserved?", options: { E: "Outgoing", I: "Reserved" } },
  { question: "Do you prefer to focus on the big picture or the details?", options: { N: "Big Picture", S: "Details" } },
  { question: "Do you make decisions based on logic or feelings?", options: { T: "Logic", F: "Feelings" } },
  { question: "Do you prefer a structured or flexible lifestyle?", options: { J: "Structured", P: "Flexible" } },
  // Add more questions here...
];

let currentQuestion = 0;
let personalityType = "";

const startQuizBtn = document.getElementById('startQuiz');
const quizSection = document.querySelector('.quiz');
const resultsSection = document.querySelector('.results');
const questionNumber = document.getElementById('questionNumber');
const questionText = document.getElementById('questionText');
const optionsContainer = document.querySelector('.options');
const prevQuestionBtn = document.getElementById('prevQuestion');
const nextQuestionBtn = document.getElementById('nextQuestion');
const retakeQuizBtn = document.getElementById('retakeQuiz');
const resultContent = document.getElementById('resultContent');

startQuizBtn.addEventListener('click', () => {
  startQuizBtn.classList.add('hidden');
  quizSection.classList.add('active');
  loadQuestion();
});

optionsContainer.addEventListener('click', (e) => {
  if (e.target.classList.contains('option')) {
    personalityType += e.target.dataset.value;
    nextQuestion();
  }
});

prevQuestionBtn.addEventListener('click', () => {
  currentQuestion--;
  personalityType = personalityType.slice(0, -1);
  loadQuestion();
});

nextQuestionBtn.addEventListener('click', () => {
  nextQuestion();
});

retakeQuizBtn.addEventListener('click', () => {
  currentQuestion = 0;
  personalityType = "";
  resultsSection.classList.remove('active');
  quizSection.classList.add('active');
  loadQuestion();
});

function loadQuestion() {
  const question = quizData[currentQuestion];
  questionNumber.textContent = currentQuestion + 1;
  questionText.textContent = question.question;
  optionsContainer.innerHTML = Object.entries(question.options).map(([value, text]) => `
    <button class="option" data-value="${value}">${text}</button>
  `).join('');
  prevQuestionBtn.disabled = currentQuestion === 0;
  nextQuestionBtn.disabled = true;
}

function nextQuestion() {
  currentQuestion++;
  if (currentQuestion < quizData.length) {
    loadQuestion();
  } else {
    showResults();
  }
}

function showResults() {
  quizSection.classList.remove('active');
  resultsSection.classList.add('active');
  const careerMatches = {
    "INTJ": "Architect",
    "INTP": "Logician",
    "ENTJ": "Commander",
    "ENTP": "Debater",
    "INFJ": "Advocate",
    "INFP": "Mediator",
    "ENFJ": "Protagonist",
    "ENFP": "Campaigner",
    "ISTJ": "Inspector",
    "ISFJ": "Defender",
    "ESTJ": "Executive",
    "ESFJ": "Consul",
    "ISTP": "Virtuoso",
    "ISFP": "Adventurer",
    "ESTP": "Entrepreneur",
    "ESFP": "Entertainer"
  };
  const result = careerMatches[personalityType] || "Unknown";
  resultContent.innerHTML = `
    <p>Your personality type is: <strong>${personalityType}</strong></p>
    <p>Your ideal career match is: <strong>${result}</strong></p>
  `;
}